@@ -3,7 +3,7 @@ from torchvision import models
 
 from torchbenchmark.network.core.unet import UNet
 
-network_name = "resnet152"
+network_name = "unet"
 
 num_classes = 1000
 
@@ -16,7 +16,7 @@ vgg = models.alexnet().to(device)
 
 import torchbenchmark.estimator.model_estimator as est
 
-input_size = (3, 227, 227)
-mest = est.ModelEstimator(name='alexnet', model=net, input_size=input_size, batch_size=2 ,save=True, save_path='stats/alexnet_info_dummy.info')
+input_size = (3, 192, 192)
+mest = est.ModelEstimator(name='unet', model=net, input_size=input_size, batch_size=8 ,save=True, save_path='stats/unet_mb_1_info_dummy.info')
 
 mest.generate_summary()
\ No newline at end of file
